==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/ronportal/user.php <==
<?php
/**
 * stanislav.elbl, 20.02.2021
 */

namespace RonPortal;


class User
{

    // prihlasovaci jmeno
    public static function getLoginName()
    {
        return isset($_SESSION['loginname']) ? $_SESSION['loginname'] : null;
    }

    public static function setLoginName($loginName)
    {
        $_SESSION['loginname'] = $loginName;
    }


    /**
     * Priznak prihlaseni
     * @return bool
     */
    public static function isAuthenticated()
    {
        return isset($_SESSION['loginauthenticated'])
            ? $_SESSION['loginauthenticated']
            : false;
    }

    public static function userAuthenticated() {
        return self::isAuthenticated();
    }


    public static function setUserAuthenticated($value)
    {
        $_SESSION['loginauthenticated'] = $value;
    }


    public static function isPasswordChangeEnabled()
    {
        return isset($_SESSION['loginpasswordchangeenabled'])
            ? $_SESSION['loginpasswordchangeenabled']
            : false;
    }

    public static function setPasswordChangeEnabled($value)
    {
        $_SESSION['loginpasswordchangeenabled'] = $value;
    }


    /**
     * Vraci plne jmeno uzivatele
     * @return string
     */
    public static function getUserName()
    {
        return isset($_SESSION['userfullname']) ? $_SESSION['userfullname'] : '';
    }

    public static function setUserName($value)
    {
        $_SESSION['userfullname'] = $value;
    }


    /**
     * Vraci RC uzivatele
     * @return string
     */
    public static function getRC()
    {
        return isset($_SESSION['rcuzivatele']) ? $_SESSION['rcuzivatele'] : '';
    }

    public static function setRC($value)
    {
        $_SESSION['rcuzivatele'] = $value;
    }

    /**
     * Vraci true, pokud ma aktualni uzivatel zadane RC
     * @param string $value
     * @return bool
     */
    public static function hasRC($value)
    {
        return !strcasecmp(self::getRC(), $value);
    }

    /**
     * Vraci kod profilu uzivatele
     * @return mixed
     */
    public static function getSkupinaUzivatele()
    {
        return isset($_SESSION['skupinauzivatele']) ? $_SESSION['skupinauzivatele'] : '';
    }

    /**
     * Vraci kod profilu uzivatele - alias k getSkupinaUzivatele
     * @return mixed
     */
    public static function getProfil()
    {
        return self::getSkupinaUzivatele();
    }

    public static function setSkupinaUzivatele($value)
    {
        $_SESSION['skupinauzivatele'] = $value;
    }

    public static function getUserCss()
    {
        return isset($_SESSION['usercssfilename']) ? $_SESSION['usercssfilename'] : '';
    }

    public static function setUserCss($value)
    {
        $_SESSION['usercssfilename'] = $value;
    }

    /**
     * Vraci prihlasovaci jmeno skutecneho uzivatele (pri zastupu a "prihlasit se jako")
     * @return mixed
     */
    public static function getRealLoginName()
    {
        return isset($_SESSION['realloginname']) ? $_SESSION['realloginname'] : '';
    }

    public static function setRealLoginName($value)
    {
        $_SESSION['realloginname'] = $value;
    }


    /**
     * Vraci RC skutecneho uzivatele (pri zastupu a "prihlasit se jako")
     * @return string
     */
    public static function getRealUserRC()
    {
        return isset($_SESSION['realuserrc']) ? $_SESSION['realuserrc'] : '';
    }

    public static function setRealUserRC($value)
    {
        $_SESSION['realuserrc'] = $value;
    }


    /**
     * Vraci true, pokud je uzivatel prihlasen jako jiny uzivatel
     * @return bool
     */
    public static function isLoggedAs()
    {
        return isset($_SESSION['realloginname'])  &&  $_SESSION['realloginname']  &&  $_SESSION['realloginname'] != self::getLoginName();
    }


    /**
     * Vraci true, pokud je uzivatel prihlasen jako zastup
     * @return bool
     */
    public static function jeZastup()
    {
        return isset($_SESSION['zastupuzivatele']) ? $_SESSION['zastupuzivatele'] : false;
    }

    public static function setZastup($value)
    {
        $_SESSION['zastupuzivatele'] = $value;
    }

    public static function getVynutitZmenuHesla()
    {
        return isset($_SESSION['vynutitzmenuhesla']) ? $_SESSION['vynutitzmenuhesla'] : null;
    }

    public static function setVynutitZmenuHesla($value)
    {
        $_SESSION['vynutitzmenuhesla'] = $value;
    }


    /**
     * Vraci true, pokud je uzivatel v zadanem profilu.
     * Pokud je $povolitOddelovac=true, muze byt zadano i vice profilu oddelenych strednikem nebo pole
     * @param string|string[] $profil
     * @param bool $povolitOddelovac
     * @return bool
     */
    public static function jeVProfilu($profil, $povolitOddelovac = true)
    {
        if (!$povolitOddelovac) {
            return !strcasecmp($profil, self::getSkupinaUzivatele());
        }

        $profily = is_array($profil)
            ? $profil
            : explode(';', $profil);

        if ($profily) {
            foreach ($profily as $kodProfilu) {
                if (!strcasecmp(self::getSkupinaUzivatele(), $kodProfilu)) {
                    return true;
                }
            }
        }

        return false;
    }
}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2305_171.zip: ronportal/ronportal/user.php <==
<?php
/**
 * stanislav.elbl, 20.02.2021
 */

namespace RonPortal;


/**
 * Spravuje informace o aktualne prihlasenem uzivateli
 */
class User
{

    /**
     * Vraci prihlasovaci jmeno aktualniho uzivatele
     * @return string|null
     */
    public static function getLoginName(): ?string
    {
        return $_SESSION['loginname'] ?? null;
    }

    /**
     * Nastavi prihlasovaci jmeno aktualniho uzivatele
     * @param string $loginName
     * @return void
     */
    public static function setLoginName($loginName)
    {
        $_SESSION['loginname'] = $loginName;
    }


    /**
     * Priznak prihlaseni - vraci true, pokud je uzivatel prihlasen
     * @return bool
     */
    public static function isAuthenticated(): bool
    {
        return $_SESSION['loginauthenticated'] ?? false;
    }

    public static function userAuthenticated() {
        return self::isAuthenticated();
    }


    public static function setUserAuthenticated($value)
    {
        $_SESSION['loginauthenticated'] = $value;
    }


    public static function isPasswordChangeEnabled()
    {
        return $_SESSION['loginpasswordchangeenabled'] ?? false;
    }

    /**
     * Vraci true, pokud je mozne zmenit heslo uzivatele (zalezi na zpusobu prihlaseni a pravech)
     * @param bool $value
     * @return void
     */
    public static function setPasswordChangeEnabled($value)
    {
        $_SESSION['loginpasswordchangeenabled'] = $value;
    }


    /**
     * Vraci plne jmeno uzivatele
     * @return string
     */
    public static function getUserName()
    {
        return $_SESSION['userfullname'] ?? '';
    }

    public static function setUserName($value)
    {
        $_SESSION['userfullname'] = $value;
    }


    /**
     * Vraci RC uzivatele
     * @return string
     */
    public static function getRC()
    {
        return $_SESSION['rcuzivatele'] ?? '';
    }

    public static function setRC($value)
    {
        $_SESSION['rcuzivatele'] = $value;
    }

    /**
     * Vraci true, pokud ma aktualni uzivatel zadane RC
     * @param string $value
     * @return bool
     */
    public static function hasRC($value)
    {
        return !strcasecmp(self::getRC(), $value);
    }

    /**
     * Vraci kod profilu uzivatele
     * @return mixed
     */
    public static function getSkupinaUzivatele()
    {
        return $_SESSION['skupinauzivatele'] ?? '';
    }

    /**
     * Vraci nazev profilu uzivatele
     * @return mixed
     */
    public static function getNazevSkupinyUzivatele()
    {
        return $_SESSION['skupinauzivatele_popis'] ?? '';
    }


    /**
     * Vraci kod profilu uzivatele - alias k getSkupinaUzivatele
     * @return mixed
     */
    public static function getProfil()
    {
        return self::getSkupinaUzivatele();
    }

    public static function setSkupinaUzivatele($value, $nazevSkupiny)
    {
        $_SESSION['skupinauzivatele'] = $value;
        $_SESSION['skupinauzivatele_popis'] = $nazevSkupiny;
    }


    /**
     * Vraci id fotografie aktualniho uzivatele
     * @return mixed|null
     */
    public static function getUserFotoId()
    {
        return $_SESSION['user_foto_id'] ?? null;
    }

    public static function setUserFotoId($id)
    {
        $_SESSION['user_foto_id'] = $id;
    }

    public static function getUserCss()
    {
        return $_SESSION['usercssfilename'] ?? '';
    }

    public static function setUserCss($value)
    {
        $_SESSION['usercssfilename'] = $value;
    }

    /**
     * Vraci prihlasovaci jmeno skutecneho uzivatele (pri zastupu a "prihlasit se jako")
     * @return mixed
     */
    public static function getRealLoginName()
    {
        return $_SESSION['realloginname'] ?? '';
    }

    public static function setRealLoginName($value)
    {
        $_SESSION['realloginname'] = $value;
    }


    /**
     * Vraci RC skutecneho uzivatele (pri zastupu a "prihlasit se jako")
     * @return string
     */
    public static function getRealUserRC()
    {
        return $_SESSION['realuserrc'] ?? '';
    }

    public static function setRealUserRC($value)
    {
        $_SESSION['realuserrc'] = $value;
    }


    /**
     * Vraci true, pokud je uzivatel prihlasen jako jiny uzivatel
     * @return bool
     */
    public static function isLoggedAs()
    {
        return isset($_SESSION['realloginname'])  &&  $_SESSION['realloginname']  &&  $_SESSION['realloginname'] != self::getLoginName();
    }


    /**
     * Vraci true, pokud je uzivatel prihlasen jako zastup
     * @return bool
     */
    public static function jeZastup()
    {
        return $_SESSION['zastupuzivatele'] ?? false;
    }

    public static function setZastup($value)
    {
        $_SESSION['zastupuzivatele'] = $value;
    }

    public static function getVynutitZmenuHesla()
    {
        return $_SESSION['vynutitzmenuhesla'] ?? null;
    }

    public static function setVynutitZmenuHesla($value)
    {
        $_SESSION['vynutitzmenuhesla'] = $value;
    }


    /**
     * Vraci true, pokud je uzivatel v zadanem profilu.
     * Pokud je $povolitOddelovac=true, muze byt zadano i vice profilu oddelenych strednikem nebo pole
     * @param string|string[] $profil
     * @param bool $povolitOddelovac
     * @return bool
     */
    public static function jeVProfilu($profil, $povolitOddelovac = true)
    {
        if (!$povolitOddelovac) {
            return !strcasecmp($profil, self::getSkupinaUzivatele());
        }

        $profily = is_array($profil)
            ? $profil
            : explode(';', $profil);

        if ($profily) {
            foreach ($profily as $kodProfilu) {
                if (!strcasecmp(self::getSkupinaUzivatele(), $kodProfilu)) {
                    return true;
                }
            }
        }

        return false;
    }
}
